@@ -38,6 +38,12 @@ module Bustle.Types
   , unOtherName
   , unBusName
 
+  , NameFilter(..)
+  , emptyNameFilter
+  , nameFilterAddOnly
+  , nameFilterAddNever
+  , nameFilterRemove
+
   , dbusName
   , dbusInterface
 
@@ -68,6 +74,8 @@ import DBus ( ObjectPath, formatObjectPath
             )
 import Data.Maybe (maybeToList)
 import Data.Either (partitionEithers)
+import Data.Set (Set)
+import qualified Data.Set as Set
 
 type Serial = Word32
 
@@ -95,6 +103,33 @@ unBusName :: TaggedBusName -> String
 unBusName (U (UniqueName x)) = formatBusName x
 unBusName (O (OtherName  x)) = formatBusName x
 
+data NameFilter =
+    NameFilter { nfOnly :: Set UniqueName
+               , nfNever :: Set UniqueName
+               }
+  deriving
+    (Show, Eq, Ord)
+
+emptyNameFilter :: NameFilter
+emptyNameFilter = NameFilter Set.empty Set.empty
+
+nameFilterModify :: (Set UniqueName -> Set UniqueName)
+                 -> (Set UniqueName -> Set UniqueName)
+                 -> NameFilter
+                 -> NameFilter
+nameFilterModify updateOnly updateNever nf =
+    nf { nfOnly = updateOnly $ nfOnly nf
+       , nfNever = updateNever $ nfNever nf
+       }
+
+nameFilterAddOnly, nameFilterAddNever, nameFilterRemove
+    :: UniqueName
+    -> NameFilter
+  -> NameFilter
+nameFilterAddOnly u  = nameFilterModify (Set.insert u) (Set.delete u)
+nameFilterAddNever u = nameFilterModify (Set.delete u) (Set.insert u)
+nameFilterRemove u   = nameFilterModify (Set.delete u) (Set.delete u)
+
 -- These useful constants disappeared from dbus in the grand removing of the
 -- -core suffix.
 dbusName :: BusName
